@@ -1,4 +1,4 @@
 from .monument_name import MonumentNameToImage
 from .time_parser import TimeParser
 from .coord_util import CoordUtil
-from .error_checher import ErrorChecker
\ No newline at end of file
+from .error_checker import ErrorChecker
\ No newline at end of file
